@@ -316,21 +316,21 @@ where
     fn parse(&mut self) -> PResult<KeyframesRule> {
         let span = self.input.cur_span()?;
         let name = match bump!(self) {
-            Token::Ident { value, raw } => Ident {
+            Token::Ident { value, raw } => KeyframesName::Ident(Ident {
                 span: span!(self, span.lo),
                 value,
                 raw,
-            },
-            Token::Str { value, raw } => Ident {
+            }),
+            Token::Str { value, raw } => KeyframesName::Str(Str {
                 span: span!(self, span.lo),
                 value,
                 raw,
-            },
-            _ => Ident {
+            }),
+            _ => KeyframesName::Ident(Ident {
                 span: DUMMY_SP,
                 value: js_word!(""),
                 raw: js_word!(""),
-            },
+            }),
         };
         let mut blocks = vec![];
 
@@ -347,7 +347,7 @@ where
 
         return Ok(KeyframesRule {
             span: span!(self, span.lo),
-            id: name,
+            name,
             blocks,
         });
     }
